# readme
>  education as life

与生活相关的小案例

### 快看书!
如果有人开门则切换屏幕

subprocess
    shell命令

解析json
pprint

### 声控灯
pygame

### 情绪灯光
opencv

### GUI开关
guizero

Pygame/Pygame Zero

play

p5py

[Play: 像学习Scratch那样学习Python](https://blog.just4fun.site/replit-play.html)

### 做一个手柄
keyboard HCI

### 微信关灯
itchat

### jupyter lab
jupyter lab --notebook-dir=~/codelab_adapter